BuildOutputFilter

Struct BuildOutputFilter 

pub struct BuildOutputFilter {
    pub suppress: Vec<String>,
    pub highlight: Vec<String>,
    pub min_level: BuildLogLevel,
}
Filters build output to suppress or highlight certain messages.

Fields

suppress: Vec<String>

Suppress lines matching these substrings.

highlight: Vec<String>

Highlight lines matching these substrings.

min_level: BuildLogLevel

Minimum log level to show.

Implementations

Source

impl BuildOutputFilter

pub fn new() -> Self

Create a default filter (show everything, highlight nothing).

pub fn suppress(self, pattern: &str) -> Self

Add a suppression pattern.

pub fn highlight(self, pattern: &str) -> Self

Add a highlight pattern.

pub fn min_level(self, level: BuildLogLevel) -> Self

Set minimum level.

pub fn should_show(&self, level: BuildLogLevel, text: &str) -> bool

Whether a message at level with text should be shown.

pub fn should_highlight(&self, text: &str) -> bool

Whether a message should be highlighted.