BuildPathResolver

Struct BuildPathResolver 

pub struct BuildPathResolver { /* private fields */ }
Utility for resolving relative paths within the build directory.

Implementations

Source

impl BuildPathResolver

pub fn new(root: impl Into<PathBuf>, out: impl Into<PathBuf>) -> Self

Create a resolver anchored at root with output in out.

pub fn source_path(&self, rel: &str) -> PathBuf

Source path relative to root.

pub fn output_path(&self, rel: &str) -> PathBuf

Output path relative to out directory.

pub fn object_path(&self, module: &str) -> PathBuf

Object file path for a given module name.

pub fn interface_path(&self, module: &str) -> PathBuf

Interface file path for a given module name.