pub struct BuildOutputFilter {
pub suppress: Vec<String>,
pub highlight: Vec<String>,
pub min_level: BuildLogLevel,
}Expand description
Filters build output to suppress or highlight certain messages.
Fields
suppress: Vec<String>Suppress lines matching these substrings.
highlight: Vec<String>Highlight lines matching these substrings.
min_level: BuildLogLevelMinimum log level to show.
Implementations
Sourceimpl BuildOutputFilter
impl BuildOutputFilter
Sourcepub fn min_level(self, level: BuildLogLevel) -> Self
pub fn min_level(self, level: BuildLogLevel) -> Self
Set minimum level.
Sourcepub fn should_show(&self, level: BuildLogLevel, text: &str) -> bool
pub fn should_show(&self, level: BuildLogLevel, text: &str) -> bool
Whether a message at level with text should be shown.
Sourcepub fn should_highlight(&self, text: &str) -> bool
pub fn should_highlight(&self, text: &str) -> bool
Whether a message should be highlighted.