pub struct BuildPathResolver { /* private fields */ }Expand description
Utility for resolving relative paths within the build directory.
Implementations
Sourceimpl BuildPathResolver
impl BuildPathResolver
Sourcepub fn new(root: impl Into<PathBuf>, out: impl Into<PathBuf>) -> Self
pub fn new(root: impl Into<PathBuf>, out: impl Into<PathBuf>) -> Self
Create a resolver anchored at root with output in out.
Sourcepub fn source_path(&self, rel: &str) -> PathBuf
pub fn source_path(&self, rel: &str) -> PathBuf
Source path relative to root.
Sourcepub fn output_path(&self, rel: &str) -> PathBuf
pub fn output_path(&self, rel: &str) -> PathBuf
Output path relative to out directory.
Sourcepub fn object_path(&self, module: &str) -> PathBuf
pub fn object_path(&self, module: &str) -> PathBuf
Object file path for a given module name.
Sourcepub fn interface_path(&self, module: &str) -> PathBuf
pub fn interface_path(&self, module: &str) -> PathBuf
Interface file path for a given module name.